==> hoteldruid-mod-id_3.0.6-1.tar.gz: id/modifica_contratto.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Kembali"; break;
case "documento":  				$messaggio = "dokumen"; break;
case "Modifica il documento":  			$messaggio = "Ubah dokumen"; break;
case "Salva le modifiche":  			$messaggio = "Simpan perubahan"; break;
case "Visualizza il documento":  		$messaggio = "Lihat dokumen"; break;
case "Documento salvato":  			$messaggio = "Dokumen disimpan"; break;
case "Aggiungi":  				$messaggio = "Tambah"; break;
case "Cambia":  				$messaggio = "Ubah"; break;
case "Formato del documento":  			$messaggio = "Format dokumen"; break;
case "Elimina":  				$messaggio = "Hapus"; break;
case "Mandare una copia bcc":  			$messaggio = "Kirim sebagai bcc copy"; break;
case "al mittente":  				$messaggio = "kepada pengirim"; break;
case "Allegato salvato":  			$messaggio = "Attachment disimpan"; break;
case "Allegato eliminato":  			$messaggio = "Attachment dihapus"; break;
case "ripetizione prenotazioni":  		$messaggio = "pengulangan reservasi"; break;
case "ripetizione ospiti":  			$messaggio = "pengulangan tamu"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI PRENOTAZIONE":	$messaggio = "GANTI SETIAP BAGIAN YANG AKAN DIULANG UNTUK SETIAP RESERVASI"; break;
case "SOSTITUISCI CON LISTA OSPITI IN PRENOTAZIONE":	$messaggio = "GANTI DENGAN DAFTAR TAMU DI RESERVASI"; break;
case "SOSTITUISCI CON LISTA COSTI IN PRENOTAZIONE":	$messaggio = "GANTI DENGAN DAFTAR BIAYA DI RESERVASI"; break;
case "Salva i documenti con numero progressivo nella cartella":	$messaggio = "Simpan dokumen dengan jumlah progresif di direktoriSave documents with progressive number in the directory"; break;
case "I documenti non verranno salvati":	$messaggio = "Dokumen tidak akan disimpan"; break;
case "I documenti verranno salvati nella cartella":	$messaggio = "Dokumen akan disimpan di direktori"; break;
case "valore":  				$messaggio = "nilai"; break;
case "OPPURE":  				$messaggio = "OR"; break;
case "in":  					$messaggio = "in"; break;
case "al":  					$messaggio = "to"; break;
case "e":  					$messaggio = "and"; break;
case "Modifica Documento":  			$messaggio = "Modify Document"; break;
case "Variabili":  				$messaggio = "Variables"; break;
case "Limiti":  				$messaggio = "Limits of"; break;
case "EMAIL":  					$messaggio = "EMAIL"; break;
case "Oggetto":  				$messaggio = "Subject"; break;
case "Formato del documento cambiato":  	$messaggio = "Document format changed"; break;
case "Oggetto cambiato":  			$messaggio = "Subject changed"; break;
case "Allegato":  				$messaggio = "Attachment"; break;
case "all'indirizzo":  				$messaggio = "to the address"; break;
case "Copie bcc da spedire cambiate":  		$messaggio = "Bcc copies to be sent changed"; break;
case "ripetizione costi aggiuntivi":  		$messaggio = "extra costs repetition"; break;
case "ripetizione array":  			$messaggio = "array repetition"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY":	$messaggio = "REPLACE WITH PART TO BE REPEATED FOR EACH ARRAY VALUE"; break;
case "Errore nelle ripetizioni e condizioni annidate":	$messaggio = "Error in nested loops and conditions"; break;
case "parte sotto condizione":  		$messaggio = "part under condition"; break;
case "nome_variabile":  			$messaggio = "variable_name"; break;
case "SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE":	$messaggio = "REPLACE WITH PART TO BE SHOWN ONLY IF PREVIOUS CONDITION IS SATISFIED"; break;
case "Variabili personalizzate e condizioni del documento":	$messaggio = "Custom variables and conditions of document"; break;
case "Condividi il numero progressivo con":  	$messaggio = "Share progressive number with"; break;
case "il documento":  				$messaggio = "document"; break;
case "Usa come nome del file":  		$messaggio = "Use as file name"; break;
case "il nome del documento":  			$messaggio = "the document name"; break;
case "un altro nome":  				$messaggio = "another name"; break;
case "non condividerà il numero progressivo con nessun documento":	$messaggio = "will not share progressive number with any document"; break;
case "condividerà il numero progressivo con il documento":	$messaggio = "will share progressive number with document"; break;
case "I file verranno salvati con il nome del documento":	$messaggio = "Files will be saved with the document name"; break;
case "I file verranno salvati con il nome":  	$messaggio = "Files will be saved with name"; break;
case "Salva automaticamente il documento":  	$messaggio = "Save the document automatically"; break;
case "mai":  					$messaggio = "never"; break;
case "alla registrazione dell'entrata":  	$messaggio = "at check-in"; break;
case "alla registrazione dell'uscita":  	$messaggio = "at check-out"; break;
case "Il documento verrà salvato automaticamente":	$messaggio = "The document will be saved automatically"; break;
case "Il documento non verrà salvato automaticamente":	$messaggio = "The document will not be saved automatically"; break;
case "multi-lingua":  				$messaggio = "multi-language"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nei documenti in formato multi-lingua non è possibile ripetere una sola parte con i tag [r] e [/r], il documento viene ripetuto interamente per ogni prenotazione":	$messaggio = "with multi-language format it's not possible to repeat only one part under the tags [r] and [/r], the document is repeated entirely for each reservation"; break;
case "predefinito":  				$messaggio = "default"; break;
case "fai predefinito":  			$messaggio = "make default"; break;
case "Comprimi i file":  			$messaggio = "Compress files"; break;
case "Il documento non verrà salvato compresso su disco":	$messaggio = "The document will not be saved compressed on disk"; break;
case "Il documento verrà salvato compresso su disco":	$messaggio = "The document will be saved compressed on disk"; break;
case "Formato dell'email":  			$messaggio = "Email format"; break;
case "testo semplice":  			$messaggio = "plain text"; break;
case "html":  					$messaggio = "html"; break;
case "Formato dell'email cambiato":  		$messaggio = "Email format changed"; break;
case "ripetizione pagamenti":  			$messaggio = "payments repetition"; break;
case "ripetizione unità":  			$messaggio = "units repetition"; break;
case "SOSTITUISCI CON LISTA PAGAMENTI":  	$messaggio = "REPLACE WITH LIST OF PAYMENTS"; break;
case "Intestazione html personalizzata":  	$messaggio = "Custom html head"; break;
case "Modifica l'intestazione html":  		$messaggio = "Modify html head"; break;
case "Modifica la chiusura html":  		$messaggio = "Modify html foot"; break;
case "Intestazione html cambiata":  		$messaggio = "Html head changed"; break;
case "Chiusura html cambiata":  		$messaggio = "Html foot changed"; break;
case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Increase the progressive number each time that it appears"; break;
case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Each document will have a unique progressive number"; break;
case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "The progressive number will be increased each time it appears in the document"; break;
case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extension for viewing and downloading the document"; break;
case "Nome con cui vedere e scaricare il documento":	$messaggio = "Name for viewing and downloading the document"; break;
case "predefinita":  				$messaggio = "default"; break;
case "personalizzata":  			$messaggio = "custom"; break;
case "Estensione cambiata":  			$messaggio = "Extension changed"; break;
case "Considera questo documento come una API":	$messaggio = "Consider this document as an API"; break;
case "Il documento verrà considerato come una API":	$messaggio = "The document will be considered as an API"; break;
case "Il documento non verrà più considerato come una API":	$messaggio = "The document will no longer be considered as an API"; break;
case "Password":  				$messaggio = "Password"; break;
case "La password per la API del documento è stata cambiata":	$messaggio = "The password for document API has been changed"; break;
case "Esempi di URL per chiamare il documento":	$messaggio = "Examples of URLs to call the document"; break;
case "Tutte le prenotazioni dell'anno":  	$messaggio = "All reservations from year"; break;
case "Mostra il documento come visto dall'utente":	$messaggio = "Show the document as seen by user"; break;
case "L'utente per la API del documento è stato cambiato":	$messaggio = "The user for docuemnt API has been changed"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "se la variabile":  			$messaggio = "if the variable"; break;
case "non è presente nella URL allora verranno usate le prenotazioni dell'anno corrente":	$messaggio = "is not present in the URL then reservations from current year will be used"; break;
case "Tutte le prenotazioni presenti dal":  	$messaggio = "All the reservations present from"; break;
case "si possono usare anche le parole":  	$messaggio = "you can also use the words"; break;
case "come date":  				$messaggio = "as dates"; break;
case "Tutte le prenotazioni con numero dal":  	$messaggio = "All the reservations with numbers from"; break;
case "Altri esempi dell'uso della variabile":  	$messaggio = "Other examples of the use of variable"; break;
case "Tutte le prenotazioni inserite dal":  	$messaggio = "All reservations inserted from"; break;
case "Tutti gli arrivi del":  			$messaggio = "All arrivals on"; break;
case "Tutti le partenze del":  			$messaggio = "All departures on"; break;
case "Tutti i clienti":  			$messaggio = "All the clients"; break;
case "escludendo gli ospiti":  			$messaggio = "excluding guests"; break;
case "inclusi gli ospiti":  			$messaggio = "including guests"; break;
case "ripetizione documenti salvati":  		$messaggio = "saved documents repetition"; break;
case "formato dell'utente":  			$messaggio = "format from user"; break;
case "Formato dei soldi":  			$messaggio = "Money format"; break;
case "Formato delle date":  			$messaggio = "Dates format"; break;
case "Formati predefiniti del documento cambiati":	$messaggio = "Default formats for the document changed"; break;
case "i documenti esistenti non verranno mai sovrascritti, ogni volta che si chiama la API verrà salvato un nuovo documento":	$messaggio = "existing documents will never be overwritten, each time the API is called a new document will be saved"; break;
case "Tutti i pagamenti nella cassa":  		$messaggio = "All payments in cashbox"; break;
case "nome_cassa":  				$messaggio = "cashbox_name"; break;
case "nome del documento o del file salvato":  	$messaggio = "document name or saved file name"; break;
case "variabile":  				$messaggio = "variable"; break;
case "Verrà usato il nome del documento (o il nome del file salvato) come nome per il file scaricato":	$messaggio = "The name of the document (or the name of the saved file) will be used as the name for the downloaded file"; break;
case "Verrà usato il valore della variabile":  	$messaggio = "The value of the variable"; break;
case "come nome del file scaricato":  		$messaggio = "will be used as the name for the downloaded file"; break;
case "escludendo l'estensione":  		$messaggio = "excluding extension"; break;
case "Se la variabile non è definita verrà usato il nome del documento":	$messaggio = "If the variable is not defined then the document name will be used"; break;
case "È comunque possibile mostrare <em>una sola ripetizione per ogni cliente</em> usando le variabili":	$messaggio = "However, it is possible to show <em>only one repetition per client</em> using variables"; break;
case "in una condizione come questa":  		$messaggio = "in a condition like this one"; break;
case "aggiungi ora questa condizione al documento":	$messaggio = "add now this condition to the document"; break;
case "Così i dati delle ripetizioni precedenti possono essere memorizzati in uno o più array della variabile":	$messaggio = "This way data from previous repetitions can be stored in one or more arrays of variable"; break;
case "È stato trovato un allegato uguale":  	$messaggio = "An identical attachment was found"; break;
case "riutilizzare l'allegato esistente o renderlo predefinito per evitare di ingombreare il database":	$messaggio = "reuse the existing attachment or make it the default to avoid cluttering the database"; break;
case "Unisci più condizioni con":  		$messaggio = "Merge multiple conditions with"; break;
case "sempre da sinistra a destra":  		$messaggio = "always from left to right"; break;
case "Indirizzi IP":  				$messaggio = "IP addresses"; break;
case "lista separata da virgole, qualsiasi IP se vuota":	$messaggio = "comma separated list, any IP if empty"; break;
case "Gli indirizzi IP da cui è permesso accedere alla API del documento sono stati cambiati":	$messaggio = "The IP addresses allowed to access the document API have been changed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-id_3.0.7-1.tar.gz: id/modifica_contratto.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Kembali"; break;
case "documento":  				$messaggio = "dokumen"; break;
case "Modifica il documento":  			$messaggio = "Ubah dokumen"; break;
case "Salva le modifiche":  			$messaggio = "Simpan perubahan"; break;
case "Visualizza il documento":  		$messaggio = "Lihat dokumen"; break;
case "Documento salvato":  			$messaggio = "Dokumen disimpan"; break;
case "Aggiungi":  				$messaggio = "Tambah"; break;
case "Cambia":  				$messaggio = "Ubah"; break;
case "Formato del documento":  			$messaggio = "Format dokumen"; break;
case "Elimina":  				$messaggio = "Hapus"; break;
case "Mandare una copia bcc":  			$messaggio = "Kirim sebagai bcc copy"; break;
case "al mittente":  				$messaggio = "kepada pengirim"; break;
case "Allegato salvato":  			$messaggio = "Attachment disimpan"; break;
case "Allegato eliminato":  			$messaggio = "Attachment dihapus"; break;
case "ripetizione prenotazioni":  		$messaggio = "pengulangan reservasi"; break;
case "ripetizione ospiti":  			$messaggio = "pengulangan tamu"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI PRENOTAZIONE":	$messaggio = "GANTI SETIAP BAGIAN YANG AKAN DIULANG UNTUK SETIAP RESERVASI"; break;
case "SOSTITUISCI CON LISTA OSPITI IN PRENOTAZIONE":	$messaggio = "GANTI DENGAN DAFTAR TAMU DI RESERVASI"; break;
case "SOSTITUISCI CON LISTA COSTI IN PRENOTAZIONE":	$messaggio = "GANTI DENGAN DAFTAR BIAYA DI RESERVASI"; break;
case "Salva i documenti con numero progressivo nella cartella":	$messaggio = "Simpan dokumen dengan jumlah progresif di direktoriSave documents with progressive number in the directory"; break;
case "I documenti non verranno salvati":	$messaggio = "Dokumen tidak akan disimpan"; break;
case "I documenti verranno salvati nella cartella":	$messaggio = "Dokumen akan disimpan di direktori"; break;
case "valore":  				$messaggio = "nilai"; break;
case "OPPURE":  				$messaggio = "OR"; break;
case "in":  					$messaggio = "in"; break;
case "al":  					$messaggio = "to"; break;
case "e":  					$messaggio = "and"; break;
case "o":  					$messaggio = "or"; break;
case "Modifica Documento":  			$messaggio = "Modify Document"; break;
case "Variabili":  				$messaggio = "Variables"; break;
case "Limiti":  				$messaggio = "Limits of"; break;
case "EMAIL":  					$messaggio = "EMAIL"; break;
case "Oggetto":  				$messaggio = "Subject"; break;
case "Formato del documento cambiato":  	$messaggio = "Document format changed"; break;
case "Oggetto cambiato":  			$messaggio = "Subject changed"; break;
case "Allegato":  				$messaggio = "Attachment"; break;
case "all'indirizzo":  				$messaggio = "to the address"; break;
case "Copie bcc da spedire cambiate":  		$messaggio = "Bcc copies to be sent changed"; break;
case "ripetizione costi aggiuntivi":  		$messaggio = "extra costs repetition"; break;
case "ripetizione array":  			$messaggio = "array repetition"; break;
case "SOSTITUISCI CON PARTE DA RIPETERE PER OGNI VALORE DELL'ARRAY":	$messaggio = "REPLACE WITH PART TO BE REPEATED FOR EACH ARRAY VALUE"; break;
case "Errore nelle ripetizioni e condizioni annidate":	$messaggio = "Error in nested loops and conditions"; break;
case "parte sotto condizione":  		$messaggio = "part under condition"; break;
case "nome_variabile":  			$messaggio = "variable_name"; break;
case "SOSTITUISCI CON PARTE DA MOSTRARE SOLO SE E' SODDISFATTA LA CONDIZIONE PRECEDENTE":	$messaggio = "REPLACE WITH PART TO BE SHOWN ONLY IF PREVIOUS CONDITION IS SATISFIED"; break;
case "Variabili personalizzate e condizioni del documento":	$messaggio = "Custom variables and conditions of document"; break;
case "Condividi il numero progressivo con":  	$messaggio = "Share progressive number with"; break;
case "il documento":  				$messaggio = "document"; break;
case "Usa come nome del file":  		$messaggio = "Use as file name"; break;
case "il nome del documento":  			$messaggio = "the document name"; break;
case "un altro nome":  				$messaggio = "another name"; break;
case "non condividerà il numero progressivo con nessun documento":	$messaggio = "will not share progressive number with any document"; break;
case "condividerà il numero progressivo con il documento":	$messaggio = "will share progressive number with document"; break;
case "I file verranno salvati con il nome del documento":	$messaggio = "Files will be saved with the document name"; break;
case "I file verranno salvati con il nome":  	$messaggio = "Files will be saved with name"; break;
case "Salva automaticamente il documento":  	$messaggio = "Save the document automatically"; break;
case "mai":  					$messaggio = "never"; break;
case "alla registrazione dell'entrata":  	$messaggio = "at check-in"; break;
case "alla registrazione dell'uscita":  	$messaggio = "at check-out"; break;
case "Il documento verrà salvato automaticamente":	$messaggio = "The document will be saved automatically"; break;
case "Il documento non verrà salvato automaticamente":	$messaggio = "The document will not be saved automatically"; break;
case "multi-lingua":  				$messaggio = "multi-language"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nei documenti in formato multi-lingua non è possibile ripetere una sola parte con i tag [r] e [/r], il documento viene ripetuto interamente per ogni prenotazione":	$messaggio = "with multi-language format it's not possible to repeat only one part under the tags [r] and [/r], the document is repeated entirely for each reservation"; break;
case "predefinito":  				$messaggio = "default"; break;
case "fai predefinito":  			$messaggio = "make default"; break;
case "Comprimi i file":  			$messaggio = "Compress files"; break;
case "Il documento non verrà salvato compresso su disco":	$messaggio = "The document will not be saved compressed on disk"; break;
case "Il documento verrà salvato compresso su disco":	$messaggio = "The document will be saved compressed on disk"; break;
case "Formato dell'email":  			$messaggio = "Email format"; break;
case "testo semplice":  			$messaggio = "plain text"; break;
case "html":  					$messaggio = "html"; break;
case "Formato dell'email cambiato":  		$messaggio = "Email format changed"; break;
case "ripetizione pagamenti":  			$messaggio = "payments repetition"; break;
case "ripetizione unità":  			$messaggio = "units repetition"; break;
case "SOSTITUISCI CON LISTA PAGAMENTI":  	$messaggio = "REPLACE WITH LIST OF PAYMENTS"; break;
case "Intestazione html personalizzata":  	$messaggio = "Custom html head"; break;
case "Modifica l'intestazione html":  		$messaggio = "Modify html head"; break;
case "Modifica la chiusura html":  		$messaggio = "Modify html foot"; break;
case "Intestazione html cambiata":  		$messaggio = "Html head changed"; break;
case "Chiusura html cambiata":  		$messaggio = "Html foot changed"; break;
case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Increase the progressive number each time that it appears"; break;
case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Each document will have a unique progressive number"; break;
case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "The progressive number will be increased each time it appears in the document"; break;
case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extension for viewing and downloading the document"; break;
case "Nome con cui vedere e scaricare il documento":	$messaggio = "Name for viewing and downloading the document"; break;
case "predefinita":  				$messaggio = "default"; break;
case "personalizzata":  			$messaggio = "custom"; break;
case "Estensione cambiata":  			$messaggio = "Extension changed"; break;
case "Considera questo documento come una API":	$messaggio = "Consider this document as an API"; break;
case "Il documento verrà considerato come una API":	$messaggio = "The document will be considered as an API"; break;
case "Il documento non verrà più considerato come una API":	$messaggio = "The document will no longer be considered as an API"; break;
case "Password":  				$messaggio = "Password"; break;
case "La password per la API del documento è stata cambiata":	$messaggio = "The password for document API has been changed"; break;
case "Esempi di URL per chiamare il documento":	$messaggio = "Examples of URLs to call the document"; break;
case "Tutte le prenotazioni dell'anno":  	$messaggio = "All reservations from year"; break;
case "Mostra il documento come visto dall'utente":	$messaggio = "Show the document as seen by user"; break;
case "L'utente per la API del documento è stato cambiato":	$messaggio = "The user for docuemnt API has been changed"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "se la variabile":  			$messaggio = "if the variable"; break;
case "non è presente nella URL allora verranno usate le prenotazioni dell'anno corrente":	$messaggio = "is not present in the URL then reservations from current year will be used"; break;
case "Tutte le prenotazioni presenti dal":  	$messaggio = "All the reservations present from"; break;
case "si possono usare anche le parole":  	$messaggio = "you can also use the words"; break;
case "come date":  				$messaggio = "as dates"; break;
case "Tutte le prenotazioni con numero dal":  	$messaggio = "All the reservations with numbers from"; break;
case "Altri esempi dell'uso della variabile":  	$messaggio = "Other examples of the use of variable"; break;
case "Tutte le prenotazioni inserite dal":  	$messaggio = "All reservations inserted from"; break;
case "Tutti gli arrivi del":  			$messaggio = "All arrivals on"; break;
case "Tutti le partenze del":  			$messaggio = "All departures on"; break;
case "Tutti i clienti":  			$messaggio = "All the clients"; break;
case "escludendo gli ospiti":  			$messaggio = "excluding guests"; break;
case "inclusi gli ospiti":  			$messaggio = "including guests"; break;
case "ripetizione documenti salvati":  		$messaggio = "saved documents repetition"; break;
case "formato dell'utente":  			$messaggio = "format from user"; break;
case "Formato dei soldi":  			$messaggio = "Money format"; break;
case "Formato delle date":  			$messaggio = "Dates format"; break;
case "Formati predefiniti del documento cambiati":	$messaggio = "Default formats for the document changed"; break;
case "i documenti esistenti non verranno mai sovrascritti, ogni volta che si chiama la API verrà salvato un nuovo documento":	$messaggio = "existing documents will never be overwritten, each time the API is called a new document will be saved"; break;
case "Tutti i pagamenti nella cassa":  		$messaggio = "All payments in cashbox"; break;
case "nome_cassa":  				$messaggio = "cashbox_name"; break;
case "nome del documento o del file salvato":  	$messaggio = "document name or saved file name"; break;
case "variabile":  				$messaggio = "variable"; break;
case "Verrà usato il nome del documento (o il nome del file salvato) come nome per il file scaricato":	$messaggio = "The name of the document (or the name of the saved file) will be used as the name for the downloaded file"; break;
case "Verrà usato il valore della variabile":  	$messaggio = "The value of the variable"; break;
case "come nome del file scaricato":  		$messaggio = "will be used as the name for the downloaded file"; break;
case "escludendo l'estensione":  		$messaggio = "excluding extension"; break;
case "Se la variabile non è definita verrà usato il nome del documento":	$messaggio = "If the variable is not defined then the document name will be used"; break;
case "È comunque possibile mostrare <em>una sola ripetizione per ogni cliente</em> usando le variabili":	$messaggio = "However, it is possible to show <em>only one repetition per client</em> using variables"; break;
case "in una condizione come questa":  		$messaggio = "in a condition like this one"; break;
case "aggiungi ora questa condizione al documento":	$messaggio = "add now this condition to the document"; break;
case "Così i dati delle ripetizioni precedenti possono essere memorizzati in uno o più array della variabile":	$messaggio = "This way data from previous repetitions can be stored in one or more arrays of variable"; break;
case "È stato trovato un allegato uguale":  	$messaggio = "An identical attachment was found"; break;
case "riutilizzare l'allegato esistente o renderlo predefinito per evitare di ingombreare il database":	$messaggio = "reuse the existing attachment or make it the default to avoid cluttering the database"; break;
case "Unisci più condizioni con":  		$messaggio = "Merge multiple conditions with"; break;
case "sempre da sinistra a destra":  		$messaggio = "always from left to right"; break;
case "Indirizzi IP":  				$messaggio = "IP addresses"; break;
case "lista separata da virgole, qualsiasi IP se vuota":	$messaggio = "comma separated list, any IP if empty"; break;
case "Gli indirizzi IP da cui è permesso accedere alla API del documento sono stati cambiati":	$messaggio = "The IP addresses allowed to access the document API have been changed"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "alla URL verranno cercate solo (o anche) le prenotazioni cancellate, anche nelle URL successive":	$messaggio = "to the URL will search only (or also) deleted reservations, also in subsequent URLs"; break;
case "numero del":  				$messaggio = "number from"; break;
case "prima di essere importata nel":  		$messaggio = "before being imported into"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
